<!DOCTYPE html><html class="no-js" ng-app="app" xmlns:ng="http://angularjs.org" xmlns:app="ignored"><head><meta charset="utf-8"><meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1"></head><title window-title>Buildbot</title><meta name="description" content="Buildbot web UI"><meta name="viewport" content="initial-scale=1, minimum-scale=1, user-scalable=no, maximum-scale=1, width=device-width"><link href="styles.css" rel="stylesheet"><link id="bbicon" href="img/icon.png" rel="icon"><link href="img/icon.svg" title="Buildbot" rel="fluid-icon"><div id="outdated"></div><body ng-cloak><gl-page-with-sidebar><gl-topbar><gl-topbar-contextual-actions></gl-topbar-contextual-actions><loginbar></loginbar></gl-topbar><connectionstatus></connectionstatus><ui-view></ui-view></gl-page-with-sidebar></body><script src="browser-warning.js"></script><link href="browser-warning.css" rel="stylesheet"><script src="browser-warning-list.js"></script><script>window.T =  {{ custom_templates | tojson }};</script><script src="scripts.js?_1608028663197"></script>{% for app in config.plugins -%}<script src="{{app}}/scripts.js?_1608028663197"></script><link href="{{app}}/styles.css?_1608028663197" rel="stylesheet"><script>angular.module('app').requires.push('{{app}}')</script>{% endfor %}<script>angular.module("buildbot_config", []).constant("config", {{configjson|safe}})</script></html>